@@ -24,40 +24,49 @@
 #include <qpixmap.h>
 #include <qpainter.h>
 #include <qtimer.h>
+#include <qmutex.h>
+
 /**
 @author yodor
 */
 class ChartFrame : public QWidget
 {
 Q_OBJECT
+
+	
 public:
-    ChartFrame(QWidget *parent = 0, const char *name = 0);
+    ChartFrame(int step=5, QWidget *parent = 0, const char *name = 0);
     ~ChartFrame();
 
+	void appendValue(unsigned long long int in, unsigned long long  int out);
+	enum ChartStyle{BAR=0, GRAPH};
 
-	int nextValue();
-	float getMaxRate();
-	void setMaxRate(float mrate);
-	void setValue(int index, float speed);
-	float getValue(int index);
-	void init();
-	
+	const QPixmap& getBuffer();
+	void setChartStyle(int c);
+	int getChartStyle();
+
+signals:
+	void chartStyleChange(int);
 
 public slots:
 	void clearChart();
-	void updateChart();
-	void resize(int nw);
 
 protected:
 	void paintEvent(QPaintEvent *);
+	void resizeEvent(QResizeEvent *);
+	void mouseReleaseEvent(QMouseEvent *);
 
 private:
-	float *values;
+	QMutex mutex;
+	int *vin;
+	int *vout;
+	int step_val;
+	QPixmap buf;
+	int maxRate;
 	int w;
-	int offset_w;	
-	float maxRate;
-	QPixmap *buf;
-	int num_moves;
+	void drawChart();
+	void clearArrays(int *,int *, int size);
+	int chartstyle;
 };
 
 #endif
