@@ -44,8 +44,7 @@ int KNetDockApp::newInstance()
 		//insertDockInstance();
 		//KMessageBox::messageBox(dock,KMessageBox::Error,"KNetDockApp is already running");
 	}
-	main->setShown(true);
-	main->setWindowState(main->windowState() & ~WindowMinimized | WindowActive);
+
 	return 0;
 }
 
