@@ -48,7 +48,7 @@ enum DEVTYPE {LOOP=0, PPP,  ETHER,  WIFI };
 enum DEVSTATE { UP=0, NOLINK, DOWN };
 enum DEVPRESENCE { NOTFOUND=0, PRESENT, CHECKING };
 
-typedef struct IfStat
+struct IfStat
 {
 	Q_ULLONG bytes;
 	Q_ULLONG bytes_in;
@@ -58,7 +58,7 @@ typedef struct IfStat
 	Q_ULLONG speed_out;
 };
 
-typedef struct AddrStat
+struct AddrStat
 {
 	QString ip;
 	QString mask;
@@ -66,7 +66,7 @@ typedef struct AddrStat
 	QString ptp;
 };
 
-typedef struct WiFiStat
+struct WiFiStat
 {
 	double signal_level;
 	double noise_level;
@@ -79,7 +79,7 @@ typedef struct WiFiStat
 	int txpow;
 };
 
-typedef struct WifiNetwork
+struct WifiNetwork
 {
 	QString ap_mac;
 	QString essid;
