@@ -27,7 +27,7 @@
 #include <qfile.h>
 
 
-QueryDev::QueryDev(QObject *parent): QObject(parent), fdsock(0),nlsock(0)
+QueryDev::QueryDev(QObject *parent): QObject(parent), fdsock(0),nlsock(0), firstRunComplete(false)
 {
 	fdsock = socket(AF_INET, SOCK_DGRAM, 0);
 	if(fdsock == -1)
@@ -132,6 +132,10 @@ void QueryDev::queryDevices()
 		dev_list.remove(dev_name);
 	}
 
+	if (!firstRunComplete){
+		firstRunComplete=true;
+		emit firstRunCompleted();
+	}
 }
 
 
